@@ -5,6 +5,7 @@
 #include <fstream>
 #include <algorithm>
 #include <ctime>
+#include <thread>
 
 #include <sys/stat.h>
 #include <getopt.h>
@@ -22,6 +23,7 @@
 
 using namespace std;
 
+/*
 static int read_mounts(const vector<string>& prunefs, vector<string>& mounts)
 {
 	// this doesn't include "/", as it always exists
@@ -56,6 +58,7 @@ static int read_mounts(const vector<string>& prunefs, vector<string>& mounts)
 	}
 	return 0;
 }
+*/
 
 static bool updatedb()
 {
@@ -209,7 +212,8 @@ int main(int argc, char *argv[])
 			break;
 
 		case '?':
-			break;
+			print_help_message();
+			exit(1);
 
         default:
             cerr << "Invalid getopt return value: " << opt << "\n";
@@ -253,17 +257,17 @@ int main(int argc, char *argv[])
 	}
 	elapsed("updatedb");
 
-	vector<string> fs,prunefs,mounts;
-	read_plocate(fs,prunefs, ignore_file);
-	read_mounts(prunefs,mounts);
-	elapsed("plocate");
+	vector<string> fs;
+	thread thr_plocate(read_plocate, ref(fs), ignore_file);
 
 	vector<string> packages;
 	vector<string> dpkg;
-	read_dpkg(packages, dpkg, false);
-	elapsed("dpkg");
+	thread thr_dpkg(read_dpkg, ref(packages), ref(dpkg), false);
+	thr_plocate.join();
+	thr_dpkg.join();
+	elapsed("plocate + dpkg");
 
-	map<string, owner> bugs;
+	map<string, bug> bugs;
 	read_bugs(bugs, "bugs");
 
 	// match two main data sources
@@ -361,9 +365,9 @@ int main(int argc, char *argv[])
 	cout << "---- unexplained: / ----\n";
 	for (const auto& cr: cruft4) {
 		cout << "        " << cr;
-		if (bugs.count(cr)) {
-			auto bug = bugs[cr];
-			cout << "       (Bug: #" << bug.bug << ")";
+		auto bug = bugs.find(cr);
+		if (bug != bugs.end()) {
+			cout << "       (Bug: #" << bug->second.bugno << ")";
 		}
 		cout << '\n';
 	}
