@@ -1,5 +1,7 @@
+// Copyright © 2015 Alexandre Detiste <alexandre@detiste.be>
+// SPDX-License-Identifier: GPL-2.0-or-later
+
 #include <iostream>
-#include <fstream>
 #include <algorithm>
 #include <stdio.h>
 #include <sys/stat.h>
@@ -7,13 +9,13 @@
 #include "dpkg.h"
 #include "usr_merge.h"
 
-int read_dpkg_header(vector<string>& packages)
+static int read_dpkg_header(vector<string>& packages)
 {
 	bool debug=getenv("DEBUG") != NULL;
 
 	if (debug) cerr << "DPKG DATA\n";
 	FILE* fp;
-	if ((fp = popen("dpkg-query --show --showformat '${binary:Package}\n'", "r")) == NULL) return 1;
+	if ((fp = popen("dpkg-query --show --showformat '${Package}\n' | sort -u", "r")) == NULL) return 1;
 	const int SIZEBUF = 4096;
 	char buf[SIZEBUF];
 	string package;
@@ -84,7 +86,7 @@ int read_diversions(vector<Diversion>& diversions)
 	return 0;
 }
 
-int read_dpkg_items(vector<string>& dpkg)
+static int read_dpkg_items(vector<string>& dpkg)
 {
 	bool debug=getenv("DEBUG") != NULL;
 
@@ -92,6 +94,8 @@ int read_dpkg_items(vector<string>& dpkg)
 	vector<Diversion> diversions;
 	read_diversions(diversions);
 
+	dpkg.push_back("/");
+
         string command="dpkg-query --listfiles $(dpkg-query --show --showformat '${binary:Package} ')|sort -u";
 	const int SIZEBUF = 200;
 	char buf[SIZEBUF];
@@ -140,8 +144,12 @@ int read_dpkg_items(vector<string>& dpkg)
 	return 0;
 }
 
-int read_dpkg(vector<string>& packages, vector<string>& files) {
+int read_dpkg(vector<string>& packages, vector<string>& files, bool csv) {
 	read_dpkg_header(packages);
 	read_dpkg_items(files);
+
+	// some more horrible hack for Buster backport
+	if (csv) (system("/usr/lib/cruft/csv.py")==0);
+
 	return 0;
 }
