@@ -3,8 +3,8 @@
 
 int main()
 {
-	vector<string> fs,prunefs;
-	read_plocate(fs,prunefs, "/etc/cruft/ignore");
+	vector<string> fs;
+	read_plocate(fs, "/etc/cruft/ignore");
 
 	cout << '/' << endl;
 	for (unsigned int i=0;i<fs.size();i++) {
